Reference
==================

Reference for the YTMusic class.

.. currentmodule:: ytmusicapi
.. autoclass:: YTMusic
.. automethod:: YTMusic.__init__


Setup
-----
See also the :doc:`Setup <setup/index>` page

.. autofunction:: setup
.. autofunction:: setup_oauth

Search
------
.. automethod:: YTMusic.search
.. automethod:: YTMusic.get_search_suggestions

Browsing
--------
.. automethod:: YTMusic.get_home
.. automethod:: YTMusic.get_artist
.. automethod:: YTMusic.get_artist_albums
.. automethod:: YTMusic.get_album
.. automethod:: YTMusic.get_album_browse_id
.. automethod:: YTMusic.get_user
.. automethod:: YTMusic.get_user_playlists
.. automethod:: YTMusic.get_user_videos
.. automethod:: YTMusic.get_song
.. automethod:: YTMusic.get_song_related
.. automethod:: YTMusic.get_lyrics
.. automethod:: YTMusic.get_tasteprofile
.. automethod:: YTMusic.set_tasteprofile

Explore
--------
.. automethod:: YTMusic.get_mood_categories
.. automethod:: YTMusic.get_mood_playlists
.. automethod:: YTMusic.get_charts

Watch
--------
.. automethod:: YTMusic.get_watch_playlist

Library
-------
.. automethod:: YTMusic.get_library_playlists
.. automethod:: YTMusic.get_library_songs
.. automethod:: YTMusic.get_library_albums
.. automethod:: YTMusic.get_library_artists
.. automethod:: YTMusic.get_library_subscriptions
.. automethod:: YTMusic.get_library_podcasts
.. automethod:: YTMusic.get_library_channels
.. automethod:: YTMusic.get_liked_songs
.. automethod:: YTMusic.get_saved_episodes
.. automethod:: YTMusic.get_history
.. automethod:: YTMusic.add_history_item
.. automethod:: YTMusic.remove_history_items
.. automethod:: YTMusic.rate_song
.. automethod:: YTMusic.edit_song_library_status
.. automethod:: YTMusic.rate_playlist
.. automethod:: YTMusic.subscribe_artists
.. automethod:: YTMusic.unsubscribe_artists
.. automethod:: YTMusic.get_account_info

Playlists
---------
.. automethod:: YTMusic.get_playlist
.. automethod:: YTMusic.create_playlist
.. automethod:: YTMusic.edit_playlist
.. automethod:: YTMusic.delete_playlist
.. automethod:: YTMusic.add_playlist_items
.. automethod:: YTMusic.remove_playlist_items

Podcasts
--------
.. automethod:: YTMusic.get_channel
.. automethod:: YTMusic.get_channel_episodes
.. automethod:: YTMusic.get_podcast
.. automethod:: YTMusic.get_episode
.. automethod:: YTMusic.get_episodes_playlist

Uploads
-------
.. automethod:: YTMusic.get_library_upload_songs
.. automethod:: YTMusic.get_library_upload_artists
.. automethod:: YTMusic.get_library_upload_albums
.. automethod:: YTMusic.get_library_upload_artist
.. automethod:: YTMusic.get_library_upload_album
.. automethod:: YTMusic.upload_song
.. automethod:: YTMusic.delete_upload_entity
